import argparse
import sys
import os
from .data import anime

def help():
    args = sys.argv[1:]
    if len(args) < 1:
        print( "Ayaya")
        print("to config, paste content of https://github.com/r4yish/aniinfo/blob/main/aniinfo/data/config.json\n to $HOME/.config/aniinfo/config.json")


parser = argparse.ArgumentParser()
parser.add_argument("--anime", '-a')
parser.add_argument("--manga", '-m')
parser.add_argument("--characters", '-c')

parser.add_argument("--page", '-p')
args = parser.parse_args()

if args.anime:
	anime.search_anime(args.anime, args.page)

elif args.manga:
	anime.search_manga(args.manga, args.page)

elif args.characters:
	anime.search_char(args.characters, args.page)


import os
from os.path import expanduser
import json

user_path = f"{expanduser('~')}/.config/aniinfo/config.json"
default_path = f'{os.path.dirname(__file__)}/config.json'

if os.path.exists(user_path): 
	config_path = user_path
else :
	config_path = default_path

def config_read():
	with open(config_path) as content:
		config   = json.load(content)
	return config

if __name__ == '__main__':
	print(config_read())


from setuptools import setup, find_packages

def read_requirements():
	with open('requirements.txt') as req:
		content = req.read()
		requirements = content.split('\n')
	return requirements

setup(
	name='aniinfo',
	version='0.4.1',
	packages=['aniinfo', 'aniinfo/data'],
	#data_files=[('config', ['aniinfo/data/config.json']),('requirement', ['aniinfo/data/config.json'])],
	include_package_data=True,
	install_requires=read_requirements(),
	entry_points='''
		[console_scripts]
		aniinfo=aniinfo.main:help
	'''
)